# ovf2io

ovf2io is a barebones IO package for the OOMMF Vector Field file format (OVF).

# Features

- Reading OVF files
- Writing OVF files

## Installation

```Bash
python -m pip install ovf2io
```

## Documentation

Documentation is available at [https://mcmorranlab.github.io/ovf2io/](https://mcmorranlab.github.io/ovf2io/).
